loggingLevel property
Represent the severity and importance of log messages output (.info, .debug, .error, see ScreenMeetLoggingLevel)
Implementation
String loggingLevel = ScreenMeetLoggingLevel.error;
Represent the severity and importance of log messages output (.info, .debug, .error, see ScreenMeetLoggingLevel)
String loggingLevel = ScreenMeetLoggingLevel.error;